==> prestashop_1.4.4.1.zip: prestashop/modules/livezilla/it.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{livezilla}prestashop>livezilla_2bc19baeea1dd9e939091b1d414da0f7'] = 'LiveZilla Live Help';
$_MODULE['<{livezilla}prestashop>livezilla_2b6ffc604d5470a856c3a7bba581d1ae'] = 'Chat integrata ';
$_MODULE['<{livezilla}prestashop>livezilla_c888438d14855d7d96a2724ee9c306bd'] = 'Impostazioni aggiornate';
$_MODULE['<{livezilla}prestashop>livezilla_1445650302f377af43ee1f7738dc7b50'] = 'Guida';
$_MODULE['<{livezilla}prestashop>livezilla_3e4804ddb635637d8b873f7cfee85ed5'] = 'LiveZilla non è una soluzione in hosting, il che significa che LiveZilla ha bisogno di essere installato sul computer locale (fase 1) e anche sul tuo server (fase 2) .';
$_MODULE['<{livezilla}prestashop>livezilla_f3a98489037e44119b187247b5894526'] = 'L\'installazione LiveZilla sul tuo server è chiamata Server LiveZilla.';
$_MODULE['<{livezilla}prestashop>livezilla_1965c2fd150423248634c52fc53c6e80'] = 'La guida di installazione completa è disponibile sul';
$_MODULE['<{livezilla}prestashop>livezilla_10827a74160be97df6c0873f7c9809b9'] = 'sito ufficiale LiveZilla';
$_MODULE['<{livezilla}prestashop>livezilla_0f7c0aba4acddebc7d72b7a91d339d46'] = 'Scarica ora LiveZilla!';
$_MODULE['<{livezilla}prestashop>livezilla_254f642527b45bc260048e30704edb39'] = 'Configurazione';
$_MODULE['<{livezilla}prestashop>livezilla_e6e29281ee59dd8ab5c79b21737b6430'] = 'Inserisci l\'URL della tua installazione LiveZilla';
$_MODULE['<{livezilla}prestashop>livezilla_a1c537e365d5243201b00d3ea5a1ea00'] = 'URL assoluto con il trailing slash, ad esempio,';
$_MODULE['<{livezilla}prestashop>livezilla_c718af0f8ee7235462f7c70ef974b2e7'] = '- OPPURE -';
$_MODULE['<{livezilla}prestashop>livezilla_66a4362239a5cf0c365bacbf13e98ee0'] = 'Copia / incolla lo script dato da LiveZilla';
$_MODULE['<{livezilla}prestashop>livezilla_b17f3f4dcf653a5776792498a9b44d6a'] = 'Aggiorna le impostazioni';

?>

==> prestashop_1.4.8.2.zip: prestashop/modules/livezilla/it.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{livezilla}prestashop>livezilla_2bc19baeea1dd9e939091b1d414da0f7'] = 'LiveZilla Live Help';
$_MODULE['<{livezilla}prestashop>livezilla_2b6ffc604d5470a856c3a7bba581d1ae'] = 'Chat integrata ';
$_MODULE['<{livezilla}prestashop>livezilla_c888438d14855d7d96a2724ee9c306bd'] = 'Impostazioni aggiornate';
$_MODULE['<{livezilla}prestashop>livezilla_1445650302f377af43ee1f7738dc7b50'] = 'Guida';
$_MODULE['<{livezilla}prestashop>livezilla_3e4804ddb635637d8b873f7cfee85ed5'] = 'LiveZilla non è una soluzione in hosting, il che significa che LiveZilla ha bisogno di essere installato sul computer locale (fase 1) e anche sul tuo server (fase 2) .';
$_MODULE['<{livezilla}prestashop>livezilla_f3a98489037e44119b187247b5894526'] = 'L\'installazione LiveZilla sul tuo server è chiamata Server LiveZilla.';
$_MODULE['<{livezilla}prestashop>livezilla_6dc42b5059b4c589e225323855cd1100'] = 'Una volta terminata la fase 1 e 2, è necessario compilare l\'URL della vostra installazione LiveZilla qui sotto o direttamente copia / incolla lo script nell\'area di testo. Questo integrerà LiveZilla con il tuo sito web (fase 3).';
$_MODULE['<{livezilla}prestashop>livezilla_1965c2fd150423248634c52fc53c6e80'] = 'La guida di installazione completa è disponibile sul';
$_MODULE['<{livezilla}prestashop>livezilla_10827a74160be97df6c0873f7c9809b9'] = 'sito ufficiale LiveZilla';
$_MODULE['<{livezilla}prestashop>livezilla_0f7c0aba4acddebc7d72b7a91d339d46'] = 'Scarica ora LiveZilla!';
$_MODULE['<{livezilla}prestashop>livezilla_254f642527b45bc260048e30704edb39'] = 'Configurazione';
$_MODULE['<{livezilla}prestashop>livezilla_e6e29281ee59dd8ab5c79b21737b6430'] = 'Inserisci l\'URL della tua installazione LiveZilla';
$_MODULE['<{livezilla}prestashop>livezilla_a1c537e365d5243201b00d3ea5a1ea00'] = 'URL assoluto con il trailing slash, ad esempio,';
$_MODULE['<{livezilla}prestashop>livezilla_c718af0f8ee7235462f7c70ef974b2e7'] = '- OPPURE -';
$_MODULE['<{livezilla}prestashop>livezilla_66a4362239a5cf0c365bacbf13e98ee0'] = 'Copia / incolla lo script dato da LiveZilla';
$_MODULE['<{livezilla}prestashop>livezilla_b17f3f4dcf653a5776792498a9b44d6a'] = 'Aggiorna le impostazioni';

?>
